#
# spec file for package tilda
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# FIXME incorrect-fsf-address reported upstream
# https://sourceforge.net/tracker/?func=detail&aid=3473005&group_id=126081&atid=704595

Name:           tilda
Version:        0.9.6
Release:        11.3
Summary:        A quake like terminal for GNOME
License:        GPL-2.0+
Group:          System/X11/Terminals
Url:            http://tilda.sourceforge.net/
Source0:        http://downloads.sourceforge.net/tilda/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM tilda-desktop_icon.patch sf#3473002 malcolmlewis@opensuse.org -- Fix fullpath to icon and icon file extension
Patch0:         tilda-desktop-icon.patch
# PATCH-FIX-UPSTREAM tilda-fix-pointers.patch sf#3473004 malcolmlewis@opensuse.org -- Fix 64bit-portability-issue
Patch1:         tilda-fix-pointers.patch
# PATCH-FIX-UPSTREAM tilda-fix-gdk-x11-window-set-user-time.patch bnc#633863 sf#2988694 malcolmlewis@opensuse.org -- Fix a crash
Patch2:         tilda-fix-gdk-x11-window-set-user-time.patch
# PATCH-FIX-UPSTREAM tilda-fix-glib-include.patch sf#3473000 malcolmlewis@opensuse.org -- Only <glib.h> can be included directly
Patch3:         tilda-fix-glib-include.patch
# PATCH-FIX-UPSTREAM tilda-add-xrandr-check.patch sf#3492123 malcolmlewis@opensuse.org -- Add check for the presence of the xrandr headers in configure.
Patch4:         tilda-add-xrandr-check.patch
# needed for patch4
BuildRequires:  autoconf
# needed for patch4
BuildRequires:  automake
BuildRequires:  flex
BuildRequires:  libconfuse-devel
BuildRequires:  update-desktop-files
%if 0%{?suse_version} >= 1210
BuildRequires:  vte2-devel
%else
BuildRequires:  vte-devel
%endif
%if 0%{?suse_version} > 1210
BuildRequires:  libX11-devel
BuildRequires:  libXrandr-devel
BuildRequires:  libXt-devel
%else
BuildRequires:  xorg-x11-libXt-devel
%endif
%if 0%{?suse_version} >= 1140
BuildRequires:  pkgconfig(libglade-2.0)
BuildRequires:  pkgconfig(pango)
%else
BuildRequires:  libglade2-devel
BuildRequires:  pango-devel
%endif
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Tilda is a Linux terminal taking after the likeness of many classic terminals
from first person shooter games, Quake, Doom and Half-Life (to name a few),
where the terminal has no border and is hidden from the desktop until a key is
pressed.

%lang_package
%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

# Fix glade file installed location; needs mv in %%install
sed -i 's|"tilda.glade"|"%{name}/%{name}.glade"|g' src/wizard.c

%build
# needed for patch4
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%makeinstall
mkdir -p %{buildroot}%{_datadir}/%{name}
# If removing this, then the sed hack in %%prep can be dropped too
mv %{buildroot}%{_datadir}/%{name}.glade \
   %{buildroot}%{_datadir}/%{name}/
%suse_update_desktop_file %{name}
%find_lang %{name} %{?no_lang_C}

%if 0%{?suse_version} > 1130
%post
%desktop_database_post
%endif

%if 0%{?suse_version} > 1130
%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING README ChangeLog TODO
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%files lang -f %{name}.lang

%changelog
* Thu Feb 23 2012 malcolmlewis@opensuse.org
- Add tilda-add-xrandr-check.patch: Add check for the presence of
  the xrandr headers in configure since xrandr is used in the code
  (sf#3492123).
* Tue Feb 21 2012 dimstar@opensuse.org
- Update BuildRequires after reorganization of xorg-x11 packages:
  + On 12.2/Factory and later, add libX11-devel, libXrandr-devel
    and libXt-devel.
  + Only use xorg-x11-libXt-devel on 12.1 and earlier.
* Thu Jan 12 2012 malcolmlewis@opensuse.org
- Major spec file cleanup via spec-cleaner.
- Add tilda-fix-glib-include.patch: Only <glib.h> can be included
  directly (sf#3473000).
- Add tilda-desktop-icon.patch: Fix fullpath to icon and icon file
  extension (sf#3473002).
- Upstream tilda-0.9.6-pointers.patch: Fix 64bit-portability-issue
  (sf#3473004).
- Rename tilda-0.9.6-fix-bnc633863.patch: To
  tilda-fix-gdk-x11-window-set-user-time.patch
  (bnc#633863, sf#2988694).
- Update spec file License field from GPLv2+ to GPL-2.0+ to
  conform with spdx.org identifier.
* Mon Aug 23 2010 andrea@opensuse.org
- added tilda-0.9.6-fix-bnc633863.patch to fix a segfault
  (thanks to mandriva https://qa.mandriva.com/show_bug.cgi?id=58153)
- renamed desktop_icon.patch according to packaging standards
- fixed RPM group
* Mon Feb 23 2009 mhrusecky@suse.cz
- explicit cast (tilda-0.9.6-pointers) to fix rpmlint error
- bziped sources to get rid off the last rpmlint warning
* Fri Oct 31 2008 claes.backstrom@fsfe.org
- Small fixes to build for factory
- Add GenericName to .desktop
- Remove absolute patch to icon in .desktop
- Create lang package
- Removed debug package
* Wed Aug 13 2008 claes.backstrom@fsfe.org
- Initial Package
